/* Copyright (c) 2013 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/**@file
 * @defgroup spi_master_example_main main.c
 * @{
 * @ingroup spi_master_example
 *
 * @brief SPI master example application to be used with the SPI slave example application.
 */

#include <stdio.h>
#include "spi_master.h"
#include "spi_master_config.h"
#include "nrf_delay.h"
#include "nrf_gpio.h"
#include "boards.h"
#include "xl362.h"

#define TX_RX_BUF_LENGTH 3u     /**< SPI transaction buffer length. */
#define DELAY_MS         100u   /**< Timer delay in milliseconds. */
#define LSB_FIRST         true /* */
#define MSB_FIRST         false    /* */


/**@brief Function for executing a single SPI transaction.
 *
 * @retval true  Operation success.
 * @retval false Operation failure. 
 */

static uint8_t tx_data[TX_RX_BUF_LENGTH] = {0}; 
static uint8_t rx_data[TX_RX_BUF_LENGTH] = {0};  

static bool test_spi_tx_rx(void)
{    

    uint32_t * p_spi_base_address = spi_master_init(SPI0, SPI_MODE0, MSB_FIRST);
    if (p_spi_base_address == NULL)
    {
        return false;
    }
      
		tx_data[0] = XL362_REG_WRITE;
		tx_data[1] = XL362_SOFT_RESET;
		tx_data[2] = XL362_SOFT_RESET_KEY;
    spi_master_tx_rx(p_spi_base_address, TX_RX_BUF_LENGTH, tx_data, rx_data);    
		nrf_delay_ms(DELAY_MS);

		tx_data[0] = XL362_REG_READ;
		tx_data[1] = 0x2C;
		tx_data[2] = 0x00;
    spi_master_tx_rx(p_spi_base_address, TX_RX_BUF_LENGTH, tx_data, rx_data);
		nrf_delay_ms(DELAY_MS);

		printf("%d, %d, %d", rx_data[0], rx_data[1], rx_data[2]);
		
		return true;
}


/**@brief Function for application main entry. Does not return.
 */ 
int main(void)
{
	bool is_test_success;

	// Configure all LEDs as outputs. 
	nrf_gpio_range_cfg_input(LED_START, LED_STOP,NRF_GPIO_PIN_PULLDOWN);
			
	// Set LED_0 high to indicate that the application is running. 
	//nrf_gpio_pin_set(LED_0);    

	is_test_success = test_spi_tx_rx();

	if (!is_test_success){
		//nrf_gpio_pin_set(LED_1);
	}
	
	nrf_delay_ms(DELAY_MS);
	
	
}

/** @} */
